==> BidHelper_4150_v0.02.zip: Interface/AddOns/BidHelper/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_BIDHELPERHEADER				= "BidHelper";
BINDING_NAME_BIDHELPER						= "BidHelper Toggle";

BIDHELPER_CONFIG_HEADER						= "BidHelper";
BIDHELPER_CONFIG_HEADER_INFO				= "Contains settings for the BidHelper,\nan AddOn which helps with keeping track of bids.";

BIDHELPER_ENABLED							= "Enable BidHelper";
BIDHELPER_ENABLED_INFO						= "Enables BidHelper, making it easier to keep track of bids.";

BIDHELPER_SHOW_SUCCESSFUL					= "Show successful auctions";
BIDHELPER_SHOW_SUCCESSFUL_INFO				= "Shows successful auctions entries.";

BIDHELPER_SHOW_UNSUCCESSFUL					= "Show unsuccessful auctions";
BIDHELPER_SHOW_UNSUCCESSFUL_INFO			= "Shows unsuccessful auctions entries.";

BIDHELPER_CHAT_ENABLED						= "BidHelper enabled.";
BIDHELPER_CHAT_DISABLED						= "BidHelper disabled.";

BIDHELPER_CHAT_SHOWSUCCESSFUL_ENABLED		= "BidHelper - Show Successful auctions enabled";
BIDHELPER_CHAT_SHOWSUCCESSFUL_DISABLED		= "BidHelper - Show Successful auctions disabled";
BIDHELPER_CHAT_SHOWUNSUCCESSFUL_ENABLED		= "BidHelper - Show Successful auctions enabled";
BIDHELPER_CHAT_SHOWUNSUCCESSFUL_DISABLED	= "BidHelper - Show Unsuccessful auctions disabled";

BIDHELPER_CHAT_COMMAND_INFO					= "Controls BidHelper by the command line - /bidhelper for usage.";

BIDHELPER_CHAT_COMMAND_USAGE				= "Usage: /bidhelper [state/list/successful/unsuccessful] [on/off/toggle]\nCommands:\n state - determines whether the BidHelper should be enabled or not\n list - list all bids";


BIDHELPER_TIME_TWENTYFOURHOURS				= "%02d:%02d";

BIDHELPER_LIST_HEADER						= "BidHelper:";
BIDHELPER_TOOLTIP_HEADER					= "BidHelper";
BIDHELPER_EMPTY_LIST						= "No bid messages received.";



BIDHELPER_GENERIC_MESSAGES = {
};

BIDHELPER_FAILED_MESSAGES = {
	"You have been outbid on",
	"has expired.",
	"has been cancelled by the seller"
};

BIDHELPER_SUCCESSFUL_MESSAGES = {
	" sold.",
	"You won an auction for"
};

==> BidHelper_4150_v0.03.zip: Interface/AddOns/BidHelper/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_BIDHELPERHEADER				= "BidHelper";
BINDING_NAME_BIDHELPER						= "BidHelper Toggle";

BIDHELPER_CONFIG_HEADER						= "BidHelper";
BIDHELPER_CONFIG_HEADER_INFO				= "Contains settings for the BidHelper,\nan AddOn which helps with keeping track of bids.";

BIDHELPER_ENABLED							= "Enable BidHelper";
BIDHELPER_ENABLED_INFO						= "Enables BidHelper, making it easier to keep track of bids.";

BIDHELPER_SHOW_SUCCESSFUL					= "Show successful auctions";
BIDHELPER_SHOW_SUCCESSFUL_INFO				= "Shows successful auctions entries.";

BIDHELPER_SHOW_UNSUCCESSFUL					= "Show unsuccessful auctions";
BIDHELPER_SHOW_UNSUCCESSFUL_INFO			= "Shows unsuccessful auctions entries.";

BIDHELPER_CHAT_ENABLED						= "BidHelper enabled.";
BIDHELPER_CHAT_DISABLED						= "BidHelper disabled.";

BIDHELPER_CHAT_SHOWSUCCESSFUL_ENABLED		= "BidHelper - Show Successful auctions enabled";
BIDHELPER_CHAT_SHOWSUCCESSFUL_DISABLED		= "BidHelper - Show Successful auctions disabled";
BIDHELPER_CHAT_SHOWUNSUCCESSFUL_ENABLED		= "BidHelper - Show Successful auctions enabled";
BIDHELPER_CHAT_SHOWUNSUCCESSFUL_DISABLED	= "BidHelper - Show Unsuccessful auctions disabled";

BIDHELPER_CHAT_COMMAND_INFO					= "Controls BidHelper by the command line - /bidhelper for usage.";

BIDHELPER_CHAT_COMMAND_USAGE				= "Usage: /bidhelper [state/list/successful/unsuccessful] [on/off/toggle]\nCommands:\n state - determines whether the BidHelper should be enabled or not\n list - list all bids";


BIDHELPER_TIME_TWENTYFOURHOURS				= "%02d:%02d";

BIDHELPER_LIST_HEADER						= "BidHelper:";
BIDHELPER_TOOLTIP_HEADER					= "BidHelper";
BIDHELPER_EMPTY_LIST						= "No bid messages to display.";



BIDHELPER_GENERIC_MESSAGES = {
};

BIDHELPER_FAILED_MESSAGES = {
	"You have been outbid on",
	"has expired.",
	"has been cancelled by the seller"
};

BIDHELPER_SUCCESSFUL_MESSAGES = {
	" sold.",
	"You won an auction for"
};
